@@ -15,6 +15,41 @@ __maintainer__ = "Brendan Kristiansen"
 __email__ = "b@bek.sh"
 
 
+class SerialParity:
+    """ Contains constants to specify serial parity bit
+    """
+
+    parity_none = serial.PARITY_NONE
+    parity_even = serial.PARITY_EVEN
+    parity_odd = serial.PARITY_ODD
+
+
+class SerialDataBits:
+    """ Contains constants to specify number of data bits
+    """
+
+    bits_five = serial.FIVEBITS
+    bits_six = serial.SIXBITS
+    bits_seven = serial.SEVENBITS
+    bits_eight = serial.EIGHTBITS
+
+
+class SerialStopBits:
+    """ Contains constants to specify serial stop bits
+    """
+
+    stopbits_one = serial.STOPBITS_ONE
+    stopbits_two = serial.STOPBITS_TWO
+
+
+class SerialFlowControl:
+    """ Contains constants to set up serial flow control
+    """
+
+    off = serial.XOFF
+    on = serial.XON
+
+
 class GenericInputStream:
     """ Generic input stream
     """
@@ -28,7 +63,7 @@ class GenericInputStream:
         self._raw_log_path = None
 
     @staticmethod
-    def open_stream(path: Union[str, Path], baud=4800):
+    def open_stream(path: Union[str, Path], **kwargs):
         """ Input stream factory
 
         :param path: Path to stream (file or serial port)
@@ -40,8 +75,6 @@ class GenericInputStream:
 
         if not isinstance(path, str) and not isinstance(path, Path):
             raise TypeError("Path must be a string or pathlib.Path")
-        if not isinstance(baud, int):
-            raise TypeError("Baud rate must be an integer")
 
         path = Path(path)
 
@@ -49,7 +82,7 @@ class GenericInputStream:
             raise FileNotFoundError("Specified GNSS source does not exist.")
 
         if path.is_char_device():
-            return SerialPort(path, baud=baud)
+            return SerialPort(path, **kwargs)
 
         return InputFileStream(path)
 
@@ -199,7 +232,7 @@ class SerialPort (GenericInputStream):
     _port: Path
     _baud: int
 
-    def __init__(self, path: Union[str, Path], baud: int = 4800):
+    def __init__(self, path: Union[str, Path], baud: int = 4800, **kwargs):
 
         self._stream = None
 
@@ -211,7 +244,7 @@ class SerialPort (GenericInputStream):
         self._port = Path(path)
         self._baud = baud
 
-        self._stream = serial.Serial(port=str(self._port), baudrate=self._baud)
+        self._stream = serial.Serial(port=str(self._port), baudrate=self._baud, **kwargs)
         self._stream.close()
 
         GenericInputStream.__init__(self)
