@@ -5,7 +5,7 @@ Contains a class for NMEA sentences
 https://www.gpsinformation.org/dale/nmea.htm#AAM
 """
 
-from typing import Union
+from typing import Union, List
 
 from .core import gps_time
 from . import util, sv_obs
@@ -148,15 +148,15 @@ class GNSSFixData (NMEAMessage):
 
     prefix = "GNS"
 
-    _fix_utc: str
-    _lat: float
-    _lon: float
+    _fix_utc: Union[str, None]
+    _lat: Union[float, None]
+    _lon: Union[float, None]
     _mode: str
     _sv_count: int
-    _hdop: float
-    _ortho_height: float
-    _geoidal_sep: float
-    _diff_age: float
+    _hdop: Union[float, None]
+    _ortho_height: Union[float, None]
+    _geoidal_sep: Union[float, None]
+    _diff_age: Union[float, None]
     _stat_id = None
 
     def __init__(self, msg: bytes):
@@ -171,12 +171,12 @@ class GNSSFixData (NMEAMessage):
         self._fix_utc = None if broken_msg[1] == '' else broken_msg[1]
         self._lat = None if broken_msg[2] == '' else util.format_coordinate(float(broken_msg[2]), broken_msg[3])
         self._lon = None if broken_msg[4] == '' else util.format_coordinate(float(broken_msg[4]), broken_msg[5])
-        self._mode = broken_msg[6] if broken_msg[6] != '' else "NULL"
-        self._sv_count = int(broken_msg[7]) if broken_msg[7] != '' else "NULL"
-        self._hdop = float(broken_msg[8]) if broken_msg[8] != '' else "NULL"
-        self._ortho_height = float(broken_msg[9]) if broken_msg[9] != '' else "NULL"
-        self._geoidal_sep = float(broken_msg[10]) if broken_msg[10] != '' else "NULL"
-        self._diff_age = float(broken_msg[11]) if broken_msg[11] != '' else "NULL"
+        self._mode = broken_msg[6] if broken_msg[6] != '' else "NULL"   # TODO: Do we do something about this?
+        self._sv_count = int(broken_msg[7]) if broken_msg[7] != '' else 0
+        self._hdop = float(broken_msg[8]) if broken_msg[8] != '' else None
+        self._ortho_height = float(broken_msg[9]) if broken_msg[9] != '' else None
+        self._geoidal_sep = float(broken_msg[10]) if broken_msg[10] != '' else None
+        self._diff_age = float(broken_msg[11]) if broken_msg[11] != '' else None
         self._stat_id = float(broken_msg[12].split('*')[0])
 
     def __str__(self):
@@ -226,12 +226,12 @@ class NMEADOPActiveSatsMessage (NMEAMessage):
 
     prefix = "GSA"
 
-    _fix_mode: str
-    _fix_dims: int
-    _prns: list
-    _pdop: float
-    _hdop: float
-    _vdop: float
+    _fix_mode: Union[str, None]
+    _fix_dims: Union[int, None]
+    _prns: List[int]
+    _pdop: Union[float, None]
+    _hdop: Union[float, None]
+    _vdop: Union[float, None]
 
     def __init__(self, msg: bytes):
 
@@ -289,11 +289,11 @@ class NMEASatsInViewMessage (NMEAMessage):
 
     prefix = "GSV"
 
-    _n_sentences: int
-    _sentence_num: int
-    _sv_count: int
+    _n_sentences: Union[int, None]
+    _sentence_num: Union[int, None]
+    _sv_count: Union[int, None]
 
-    _observations: list
+    _observations: List[sv_obs.SVObservation]
 
     def __init__(self, msg: bytes):
 
@@ -356,14 +356,14 @@ class NMEARMCMessage (NMEAMessage):
 
     prefix = "RMC"
 
-    _fix_time: str
-    _status: str
-    _lat: float
-    _lon: float
-    _spd_knots: float
-    _track_deg: float
-    _fix_date: str
-    _magnetic_variation: float
+    _fix_time: Union[str, None]
+    _status: Union[str, None]
+    _lat: Union[float, None]
+    _lon: Union[float, None]
+    _spd_knots: Union[float, None]
+    _track_deg: Union[float, None]
+    _fix_date: Union[str, None]
+    _magnetic_variation: Union[float, None]
 
     def __init__(self, msg: bytes):
         NMEAMessage.__init__(self, msg)
@@ -437,10 +437,10 @@ class NMEALatLonMessage (NMEAMessage):
 
     prefix = "GLL"
 
-    _lat: float
-    _lon: float
-    _fix_time: str
-    _status: str
+    _lat: Union[float, None]
+    _lon: Union[float, None]
+    _fix_time: Union[str, None]
+    _status: Union[str, None]
 
     def __init__(self, msg: bytes):
         NMEAMessage.__init__(self, msg)
@@ -477,10 +477,10 @@ class NMEAVelocityMessage (NMEAMessage):
 
     prefix = "VTG"
 
-    _track_true: float
-    _track_magnetic: float
-    _gs_knots: float
-    _gs_kmh: float
+    _track_true: Union[float, None]
+    _track_magnetic: Union[float, None]
+    _gs_knots: Union[float, None]
+    _gs_kmh: Union[float, None]
 
     def __init__(self, msg: bytes):
         NMEAMessage.__init__(self, msg)
